@@ -2,7 +2,7 @@ package Const;
 
 use strict;
 use warnings;
-use FFI::Platypus;
+use FFI::Platypus 1.00;
 
 {
   my $ffi = FFI::Platypus->new( api => 1 );
