@@ -1,13 +1,13 @@
 use strict;
 use warnings;
-use FFI::Platypus;
+use FFI::Platypus 1.00;
 
-my $ffi = FFI::Platypus->new;
+my $ffi = FFI::Platypus->new( api => 1 );
 $ffi->lib(undef);
 $ffi->type('int' => 'character');
 
-my @list = qw( 
-  alnum alpha ascii blank cntrl digit lower print punct 
+my @list = qw(
+  alnum alpha ascii blank cntrl digit lower print punct
   space upper xdigit
 );
 
