@@ -3,12 +3,12 @@ package FFI::Build::File::CXX;
 use strict;
 use warnings;
 use 5.008004;
-use base qw( FFI::Build::File::C );
+use parent qw( FFI::Build::File::C );
 use constant default_suffix => '.cxx';
 use constant default_encoding => ':utf8';
 
 # ABSTRACT: Class to track C source file in FFI::Build
-our $VERSION = '1.34'; # VERSION
+our $VERSION = '1.56'; # VERSION
 
 
 sub accept_suffix
@@ -25,7 +25,7 @@ sub cc
 sub ld
 {
   my($self) = @_;
-  $self->platform->cxx;
+  $self->platform->cxxld;
 }
 
 1;
@@ -42,7 +42,7 @@ FFI::Build::File::CXX - Class to track C source file in FFI::Build
 
 =head1 VERSION
 
-version 1.34
+version 1.56
 
 =head1 SYNOPSIS
 
@@ -80,7 +80,7 @@ Damyan Ivanov
 
 Ilya Pavlov (Ilya33)
 
-Petr Pisar (ppisar)
+Petr Písař (ppisar)
 
 Mohammad S Anwar (MANWAR)
 
@@ -90,6 +90,14 @@ Meredith (merrilymeredith, MHOWARD)
 
 Diab Jerius (DJERIUS)
 
+Eric Brine (IKEGAMI)
+
+szTheory
+
+José Joaquín Atria (JJATRIA)
+
+Pete Houston (openstrike, HOUSTON)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2015,2016,2017,2018,2019,2020 by Graham Ollis.
