@@ -6,7 +6,7 @@ use 5.008004;
 use FFI::Platypus;
 
 # ABSTRACT: An FFI function object
-our $VERSION = '1.34'; # VERSION
+our $VERSION = '1.56'; # VERSION
 
 
 use overload '&{}' => sub {
@@ -19,7 +19,7 @@ use overload '&{}' => sub {
 
 package FFI::Platypus::Function::Function;
 
-use base qw( FFI::Platypus::Function );
+use parent qw( FFI::Platypus::Function );
 
 sub attach
 {
@@ -55,7 +55,7 @@ sub sub_ref
 
 package FFI::Platypus::Function::Wrapper;
 
-use base qw( FFI::Platypus::Function );
+use parent qw( FFI::Platypus::Function );
 
 sub new
 {
@@ -127,11 +127,11 @@ FFI::Platypus::Function - An FFI function object
 
 =head1 VERSION
 
-version 1.34
+version 1.56
 
 =head1 SYNOPSIS
 
- use FFI::Platypus;
+ use FFI::Platypus 1.00;
  
  # call directly
  my $ffi = FFI::Platypus->new( api => 1 );
@@ -199,7 +199,7 @@ Damyan Ivanov
 
 Ilya Pavlov (Ilya33)
 
-Petr Pisar (ppisar)
+Petr Písař (ppisar)
 
 Mohammad S Anwar (MANWAR)
 
@@ -209,6 +209,14 @@ Meredith (merrilymeredith, MHOWARD)
 
 Diab Jerius (DJERIUS)
 
+Eric Brine (IKEGAMI)
+
+szTheory
+
+José Joaquín Atria (JJATRIA)
+
+Pete Houston (openstrike, HOUSTON)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2015,2016,2017,2018,2019,2020 by Graham Ollis.
