@@ -2,14 +2,15 @@ package FFI::Platypus::Memory;
 
 use strict;
 use warnings;
+use 5.008004;
 use FFI::Platypus;
-use base qw( Exporter );
+use Exporter qw( import );
 
 # ABSTRACT: Memory functions for FFI
-our $VERSION = '1.10'; # VERSION
+our $VERSION = '1.56'; # VERSION
 
 
-our @EXPORT = qw( malloc free calloc realloc memcpy memset strdup strndup );
+our @EXPORT = qw( malloc free calloc realloc memcpy memset strdup strndup strcpy );
 
 my $ffi = FFI::Platypus->new( api => 1 );
 $ffi->lib(undef);
@@ -22,6 +23,7 @@ $ffi->attach(calloc  => ['size_t', 'size_t']           => 'opaque' => '$$');
 $ffi->attach(realloc => ['opaque', 'size_t']           => 'opaque' => '$$');
 $ffi->attach(memcpy  => ['opaque', 'opaque', 'size_t'] => 'opaque' => '$$$');
 $ffi->attach(memset  => ['opaque', 'int', 'size_t']    => 'opaque' => '$$$');
+$ffi->attach(strcpy  => ['opaque', 'string']           => 'opaque' => '$$');
 
 my $_strdup_impl = 'not-loaded';
 sub _strdup_impl { $_strdup_impl }
@@ -31,8 +33,17 @@ eval {
   $ffi->attach(strdup  => ['string'] => 'opaque' => '$');
   $_strdup_impl = 'libc';
 };
+if($@ && $^O eq 'MSWin32')
+{
+  eval {
+    die "do not use c impl" if ($ENV{FFI_PLATYPUS_MEMORY_STRDUP_IMPL}||'libc') eq 'ffi';
+    $ffi->attach([ _strdup => 'strdup' ] => ['string'] => 'opaque' => '$');
+    $_strdup_impl = 'libc';
+  };
+}
 if($@)
 {
+  warn "using bundled strdup";
   $_strdup_impl = 'ffi';
   $ffi->attach([ ffi_platypus_memory__strdup => 'strdup' ] => ['string'] => 'opaque' => '$');
 }
@@ -51,6 +62,10 @@ if($@)
   $ffi->attach([ ffi_platypus_memory__strndup => 'strndup' ] => ['string','size_t'] => 'opaque' => '$$');
 }
 
+# used internally by FFI::Platypus::Type::WideString, may go away.
+eval { $ffi->attach( [ wcslen  => '_wcslen' ]  => [ 'opaque'           ] => 'size_t' => '$' ) };
+eval { $ffi->attach( [ wcsnlen => '_wcsnlen' ] => [ 'string', 'size_t' ] => 'size_t' => '$$' ) };
+
 1;
 
 __END__
@@ -65,7 +80,7 @@ FFI::Platypus::Memory - Memory functions for FFI
 
 =head1 VERSION
 
-version 1.10
+version 1.56
 
 =head1 SYNOPSIS
 
@@ -138,6 +153,12 @@ C<malloc>:
 
  my $pointer = realloc undef, 64; # same as malloc 64
 
+=head2 strcpy
+
+ strcpy $opaque, $string;
+
+Copies the string to the memory location pointed to by C<$opaque>.
+
 =head2 strdup
 
  my $pointer = strdup $string;
@@ -191,7 +212,7 @@ Damyan Ivanov
 
 Ilya Pavlov (Ilya33)
 
-Petr Pisar (ppisar)
+Petr Písař (ppisar)
 
 Mohammad S Anwar (MANWAR)
 
@@ -201,9 +222,17 @@ Meredith (merrilymeredith, MHOWARD)
 
 Diab Jerius (DJERIUS)
 
+Eric Brine (IKEGAMI)
+
+szTheory
+
+José Joaquín Atria (JJATRIA)
+
+Pete Houston (openstrike, HOUSTON)
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015,2016,2017,2018,2019 by Graham Ollis.
+This software is copyright (c) 2015,2016,2017,2018,2019,2020 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
